==> haskell-disk-free-space-0.1.0.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-disk-free-space.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 disk-free-space
version:              0.1.0.1
visibility:           public
id:                   disk-free-space-0.1.0.1-ITdO2vD6xRqBXbTMDAp4D7
key:                  disk-free-space-0.1.0.1-ITdO2vD6xRqBXbTMDAp4D7
license:              BSD-3-Clause
maintainer:           Marios Titas <rednebΑΤgmxDΟΤcom>
author:               Marios Titas <rednebΑΤgmxDΟΤcom>
homepage:             https://github.com/redneb/disk-free-space
synopsis:             Retrieve information about disk space usage
description:
    A cross-platform library retrieve information about disk space usage.

category:             System, Filesystem
abi:                  3e3eee2e145cb792bf4f70dd7990feb2
exposed:              True
exposed-modules:      System.DiskSpace
import-dirs:          /usr/lib/ghc-9.0.1/site-local/disk-free-space-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/disk-free-space-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/disk-free-space-0.1.0.1
hs-libraries:         HSdisk-free-space-0.1.0.1-ITdO2vD6xRqBXbTMDAp4D7
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-disk-free-space/html/disk-free-space.haddock

haddock-html:         /usr/share/doc/haskell-disk-free-space/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-disk-free-space-0.1.0.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-disk-free-space.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 disk-free-space
version:              0.1.0.1
visibility:           public
id:                   disk-free-space-0.1.0.1-AW5hNTCpMHuDdxBG2i54Pv
key:                  disk-free-space-0.1.0.1-AW5hNTCpMHuDdxBG2i54Pv
license:              BSD-3-Clause
maintainer:           Marios Titas <rednebΑΤgmxDΟΤcom>
author:               Marios Titas <rednebΑΤgmxDΟΤcom>
homepage:             https://github.com/redneb/disk-free-space
synopsis:             Retrieve information about disk space usage
description:
    A cross-platform library retrieve information about disk space usage.

category:             System, Filesystem
abi:                  d4a5da6d1581a6987911fc0848c25ba8
exposed:              True
exposed-modules:      System.DiskSpace
import-dirs:          /usr/lib/ghc-9.0.2/site-local/disk-free-space-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/disk-free-space-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/disk-free-space-0.1.0.1
hs-libraries:         HSdisk-free-space-0.1.0.1-AW5hNTCpMHuDdxBG2i54Pv
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-disk-free-space/html/disk-free-space.haddock

haddock-html:         /usr/share/doc/haskell-disk-free-space/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
